@@ -1,9 +1,10 @@
 /*
- * Copyright 2004,2005 The Apache Software Foundation.
- *
- * Licensed under the Apache License, Version 2.0 (the "License");
- * you may not use this file except in compliance with the License.
- * You may obtain a copy of the License at
+ * Licensed to the Apache Software Foundation (ASF) under one or more
+ * contributor license agreements.  See the NOTICE file distributed with
+ * this work for additional information regarding copyright ownership.
+ * The ASF licenses this file to You under the Apache License, Version 2.0
+ * (the "License"); you may not use this file except in compliance with
+ * the License.  You may obtain a copy of the License at
  *
  *      http://www.apache.org/licenses/LICENSE-2.0
  *
@@ -41,6 +42,7 @@
 #include <axutil_array_list.h>
 #include <rampart_saml_token.h>
 #include <rampart_issued_token.h>
+#include <oxs_key_mgr.h>
 
 #ifdef __cplusplus
 extern "C"
@@ -50,28 +52,86 @@ extern "C"
     typedef struct rampart_context_t rampart_context_t;
 
     typedef axis2_char_t *(AXIS2_CALL*
-                           password_callback_fn)(const axutil_env_t *env,
-                                                 const axis2_char_t *username,
-                                                 void *ctx);
+        password_callback_fn)(
+        const axutil_env_t *env,
+        const axis2_char_t *username,
+        void *user_params);
 
     typedef axis2_status_t (AXIS2_CALL*
-                            rampart_is_replayed_fn)(const axutil_env_t *env,
-                                                    axis2_msg_ctx_t* msg_ctx,
-                                                    rampart_context_t *rampart_context);
+        rampart_is_replayed_fn)(
+        const axutil_env_t *env,
+        axis2_msg_ctx_t* msg_ctx,
+        rampart_context_t *rampart_context,
+        void *user_params);
 
     typedef rampart_authn_provider_status_t (AXIS2_CALL*
-            auth_password_func)(const axutil_env_t* env,
-                                const axis2_char_t *username,
-                                const axis2_char_t *password,
-                                void *ctx);
+        auth_password_func)(
+        const axutil_env_t* env,
+        const axis2_char_t *username,
+        const axis2_char_t *password,
+        void *ctx);
 
     typedef rampart_authn_provider_status_t (AXIS2_CALL*
-            auth_digest_func)(const axutil_env_t* env,
-                              const axis2_char_t *username,
-                              const axis2_char_t *nonce,
-                              const axis2_char_t *created,
-                              const char *digest,
-                              void *ctx);
+        auth_digest_func)(
+        const axutil_env_t* env,
+        const axis2_char_t *username,
+        const axis2_char_t *nonce,
+        const axis2_char_t *created,
+        const char *digest,
+        void *ctx);
+
+    /* This function will be used to store sct. Global id, local id will be given so function 
+     * writer can store them in anyway. Get or Delete method will use any of the Global id or local 
+     * id, so Store function writer should be ready for that.
+     */
+    typedef axis2_status_t (AXIS2_CALL*
+        store_security_context_token_fn)(
+        const axutil_env_t *env, 
+        axis2_msg_ctx_t* msg_ctx, 
+        axis2_char_t *sct_global_id, 
+        axis2_char_t *sct_local_id, 
+        void *sct, 
+        void *user_params);
+
+    /* This function will be called to get previously stored sct. If secure conversation token is 
+     * referred by this method, then sct_id will be not null. However, if security context token 
+     * (pre-agreed and established offline) is refered then sct_id might be NULL. is_encryption is 
+     * passed, so that if pre-agreed sct is different for encryption and signature, then it could be 
+     * accessed. sct_id_type will be RAMPART_SCT_ID_TYPE_LOCAL or RAMPART_SCT_ID_TYPE_GLOBAL if 
+     * sct_id is NOT NULL. If sct_id is NULL, then sct_id_type will be RAMPART_SCT_ID_TYPE_UNKNOWN
+     */
+    typedef void* (AXIS2_CALL*
+        obtain_security_context_token_fn)(
+        const axutil_env_t *env, 
+        axis2_bool_t is_encryption, 
+        axis2_msg_ctx_t* msg_ctx, 
+        axis2_char_t *sct_id, 
+        int sct_id_type,
+        void* user_params);
+
+    /* This function will be called to delete previously stored sct. sct_id_type can be 
+     * RAMPART_SCT_ID_TYPE_LOCAL or RAMPART_SCT_ID_TYPE_GLOBAL
+     */
+    typedef axis2_status_t (AXIS2_CALL*
+        delete_security_context_token_fn)(
+        const axutil_env_t *env, 
+        axis2_msg_ctx_t* msg_ctx, 
+        axis2_char_t *sct_id, 
+        int sct_id_type,
+        void* user_params);
+
+    /* Validates whether security context token is valid or not. Normally, we can directly send 
+     * true as response. But if syntax of security context token is altered/added by using 
+     * extensible mechanism (e.g having sessions, etc.) then user can implement this method. 
+     * Axiom representation of the sct will be given as the parameter, because if sct is 
+     * extended, we don't know the syntax. Method writer can implement whatever needed.
+     */
+    typedef axis2_status_t (AXIS2_CALL*
+    validate_security_context_token_fn)(
+        const axutil_env_t *env, 
+        axiom_node_t *sct_node, 
+        axis2_msg_ctx_t *msg_ctx, 
+        void *user_params);
 
 	
     /**
@@ -82,7 +142,8 @@ extern "C"
     */
 
     AXIS2_EXTERN rampart_context_t *AXIS2_CALL
-    rampart_context_create(const axutil_env_t *env);
+    rampart_context_create(
+        const axutil_env_t *env);
 
 
     /**
@@ -92,8 +153,9 @@ extern "C"
     */
 
     AXIS2_EXTERN void AXIS2_CALL
-    rampart_context_free(rampart_context_t *rampart_context,
-                         const axutil_env_t *env);
+    rampart_context_free(
+        rampart_context_t *rampart_context,
+        const axutil_env_t *env);
 
 
     /****************************************************************/
@@ -246,7 +308,7 @@ extern "C"
     rampart_context_set_pwcb_function(rampart_context_t *rampart_context,
                                       const axutil_env_t *env,
                                       password_callback_fn pwcb_function,
-                                      void *ctx);
+                                      void *user_params);
     /**
      *
      * @param rampart_context
@@ -258,8 +320,19 @@ extern "C"
 
     AXIS2_EXTERN axis2_status_t AXIS2_CALL
     rampart_context_set_replay_detect_function(rampart_context_t *rampart_context,
-            const axutil_env_t *env,
-            rampart_is_replayed_fn is_replayed_function);
+        const axutil_env_t *env,
+        rampart_is_replayed_fn is_replayed_function,
+        void *user_params);
+    
+    /**
+     * @param rampart_context
+     * @param env pointer to environment struct,Must not be NULL.
+     * @returns user parameters for replay detector function or NULL
+     */
+    AXIS2_EXTERN void * AXIS2_CALL
+    rampart_context_get_rd_user_params(
+        rampart_context_t *rampart_context,
+        const axutil_env_t *env);
     /**
      *
      * @param rampart_context
@@ -284,9 +357,23 @@ extern "C"
      */
 
     AXIS2_EXTERN axis2_status_t AXIS2_CALL
-    rampart_context_set_ttl(rampart_context_t *rampart_context,
-                            const axutil_env_t *env,
-                            int ttl);
+    rampart_context_set_ttl(
+        rampart_context_t *rampart_context,
+        const axutil_env_t *env,
+        int ttl);
+
+    AXIS2_EXTERN axis2_status_t AXIS2_CALL
+    rampart_context_set_need_millisecond_precision(
+        rampart_context_t *rampart_context,
+        const axutil_env_t *env,
+        axis2_bool_t need_millisecond_precision);
+
+    AXIS2_EXTERN axis2_status_t AXIS2_CALL
+    rampart_context_set_clock_skew_buffer(
+        rampart_context_t *rampart_context,
+        const axutil_env_t *env,
+        int skew_buffer);
+
     /**
      *
      * @param rampart_context
@@ -326,20 +413,8 @@ extern "C"
     rampart_context_set_certificate_file(rampart_context_t *rampart_context,
                                          const axutil_env_t *env,
                                          axis2_char_t *certificate_file);
-    /**
-     *
-     * @param rampart_context
-     * @param env pointer to environment struct,Must not be NULL.
-     * @param reciever_cerficate_file
-     * @returns status of the op.                                                                                                        
-     * AXIS2_SUCCESS on success and AXIS2_FAILURE on error          
-     */
-
-    AXIS2_EXTERN axis2_status_t AXIS2_CALL
-    rampart_context_set_reciever_certificate_file(rampart_context_t *rampart_context,
-            const axutil_env_t *env,
-            axis2_char_t *reciever_certificate_file);
-    /**
+    
+	/**
      *
      * @param rampart_context
      * @param env pointer to environment struct,Must not be NULL.
@@ -507,8 +582,8 @@ extern "C"
      * AXIS2_SUCCESS on success and AXIS2_FAILURE on error          
      */
 
-    AXIS2_EXTERN void* AXIS2_CALL
-    rampart_context_get_ctx(
+    AXIS2_EXTERN void * AXIS2_CALL
+    rampart_context_get_pwcb_user_params(
         rampart_context_t *rampart_context,
         const axutil_env_t *env);
     /**
@@ -523,6 +598,17 @@ extern "C"
     rampart_context_get_ttl(
         rampart_context_t *rampart_context,
         const axutil_env_t *env);
+
+    AXIS2_EXTERN axis2_bool_t AXIS2_CALL
+    rampart_context_get_need_millisecond_precision(
+        rampart_context_t *rampart_context,
+        const axutil_env_t *env);
+
+    AXIS2_EXTERN int AXIS2_CALL
+    rampart_context_get_clock_skew_buffer(
+        rampart_context_t *rampart_context,
+        const axutil_env_t *env);
+
     /**
      *
      * @param rampart_context
@@ -1036,14 +1122,23 @@ extern "C"
      *
      * @param env pointer to environment struct,Must not be NULL.
      * @param token
-     * @returns status of the op.                                                                                                        
-     * AXIS2_SUCCESS on success and AXIS2_FAILURE on error          
+     * @returns whether derived key needed or not                                                                                                        
      */
-
     AXIS2_EXTERN axis2_bool_t AXIS2_CALL
     rampart_context_check_is_derived_keys(
         const axutil_env_t *env,
         rp_property_t *token);
+
+    /**
+     * @param env pointer to environment struct,Must not be NULL.
+     * @param token
+     * @returns derived key version. NULL on error.                                                                                                        
+     */
+    AXIS2_EXTERN axis2_char_t *AXIS2_CALL
+    rampart_context_get_derived_key_version(
+        const axutil_env_t *env, 
+        rp_property_t *token);
+
     /**
      *
      * @param rampart_context
@@ -1274,6 +1369,17 @@ extern "C"
     rampart_context_set_ttl_from_file(
         rampart_context_t *rampart_context,
         const axutil_env_t *env);
+
+    AXIS2_EXTERN axis2_status_t AXIS2_CALL
+    rampart_context_set_clock_skew_buffer_from_file(
+        rampart_context_t *rampart_context,
+        const axutil_env_t *env);
+
+    AXIS2_EXTERN axis2_status_t AXIS2_CALL
+    rampart_context_set_need_millisecond_precision_from_file(
+        rampart_context_t *rampart_context,
+        const axutil_env_t *env);
+
     /**
      *
      * @param rampart_context
@@ -1373,7 +1479,8 @@ extern "C"
     AXIS2_EXTERN axis2_char_t *AXIS2_CALL
     rampart_context_get_encryption_token_id(
         rampart_context_t *rampart_context,
-        const axutil_env_t *env);
+        const axutil_env_t *env, 
+        axis2_msg_ctx_t* msg_ctx);
     /**
      *
      * @param rampart_context
@@ -1385,7 +1492,8 @@ extern "C"
     AXIS2_EXTERN axis2_char_t *AXIS2_CALL
     rampart_context_get_signature_token_id(
         rampart_context_t *rampart_context,
-        const axutil_env_t *env);
+        const axutil_env_t *env, 
+        axis2_msg_ctx_t* msg_ctx);
     /**
      *
      * @param rampart_context
@@ -1399,7 +1507,8 @@ extern "C"
     rampart_context_set_encryption_token_id(
         rampart_context_t *rampart_context,
         const axutil_env_t *env,
-        axis2_char_t *sct_id);
+        axis2_char_t *sct_id, 
+        axis2_msg_ctx_t* msg_ctx);
     /**
      *
      * @param rampart_context
@@ -1413,7 +1522,8 @@ extern "C"
     rampart_context_set_signature_token_id(
         rampart_context_t *rampart_context,
         const axutil_env_t *env,
-        axis2_char_t *sct_id);
+        axis2_char_t *sct_id, 
+        axis2_msg_ctx_t* msg_ctx);
 
 
     /* Return the saml token of token type set in the rampart context */
@@ -1429,7 +1539,7 @@ extern "C"
     AXIS2_EXTERN rampart_saml_token_t * AXIS2_CALL
     rampart_context_get_saml_token(rampart_context_t *rampart_context,
                                         const axutil_env_t *env,
-										rp_property_type_t token_type);
+										rampart_st_type_t token_type);
 
     /* Add a saml token */
     /**
@@ -1454,10 +1564,11 @@ extern "C"
      * AXIS2_SUCCESS on success and AXIS2_FAILURE on error          
      */
 
-	AXIS2_EXTERN axis2_status_t AXIS2_CALL
-	rampart_context_set_saml_tokens(rampart_context_t *rampart_context,
-                                        const axutil_env_t *env,
-                                        axutil_array_list_t *tokens);
+     AXIS2_EXTERN axis2_status_t AXIS2_CALL
+    rampart_context_set_saml_tokens(
+        rampart_context_t *rampart_context,
+        const axutil_env_t *env,
+        axutil_array_list_t *tokens);
     /**
      *
      * @param rampart_context
@@ -1466,10 +1577,10 @@ extern "C"
      * AXIS2_SUCCESS on success and AXIS2_FAILURE on error          
      */
 
-	AXIS2_EXTERN issued_token_callback_func AXIS2_CALL
-	rampart_context_get_issued_token_aquire_function(
-								rampart_context_t *rampart_context, 
-								const axutil_env_t *env);  
+    AXIS2_EXTERN issued_token_callback_func AXIS2_CALL
+    rampart_context_get_issued_token_aquire_function(
+        rampart_context_t *rampart_context, 
+	const axutil_env_t *env);  
     /**
      *
      * @param rampart_context
@@ -1479,11 +1590,11 @@ extern "C"
      * AXIS2_SUCCESS on success and AXIS2_FAILURE on error          
      */
 
-	AXIS2_EXTERN axis2_status_t AXIS2_CALL
-	rampart_context_set_issued_token_aquire_function(
-								rampart_context_t *rampart_context,
-								const axutil_env_t *env,
-								issued_token_callback_func issued_token_aquire);
+    AXIS2_EXTERN axis2_status_t AXIS2_CALL
+    rampart_context_set_issued_token_aquire_function(
+        rampart_context_t *rampart_context,
+        const axutil_env_t *env,
+        issued_token_callback_func issued_token_aquire);
     /**
      *
      * @param rampart_context
@@ -1520,6 +1631,41 @@ extern "C"
     rampart_context_get_algorithmsuite(
         rampart_context_t *rampart_context,
         const axutil_env_t *env);
+    
+    /**
+     * Get the key manager from rampart context.
+     * @param rampart_context Pointer to rampart context struct.
+     * @param Pointer to environment struct
+     * @returns pointer Key manager struct
+     */
+    AXIS2_EXTERN oxs_key_mgr_t * AXIS2_CALL
+    rampart_context_get_key_mgr(
+    	rampart_context_t *rampart_context,
+    	const axutil_env_t *env);
+
+    /**
+     * Set the key manager to rampart context.
+     * @param rampart_context Pointer to rampart context struct.
+     * @param Pointer to environment struct
+     * @param key_mgr Pointer to key manager struct.
+     * @returns status of the operation. AXIS2_SUCCESS on success AXIS2_FAILURE otherwise.
+     */
+    AXIS2_EXTERN axis2_status_t AXIS2_CALL
+    rampart_context_set_key_mgr(
+        rampart_context_t *rampart_context, 
+	const axutil_env_t *env, 
+        oxs_key_mgr_t *key_mgr); 
+    
+    /**
+     * Get the pkcs12 file name from rampart context.
+     * @param rampart_context Pointer to rampart context struct.
+     * @param Pointer to environment struct
+     * @returns PKCS12 file name
+     */
+    AXIS2_EXTERN axis2_char_t *AXIS2_CALL
+    rampart_context_get_pkcs12_file_name(
+    	rampart_context_t *rampart_context,
+    	const axutil_env_t *env);
 
     /**
      * Set the a node list to the context. These nodes will be append to
@@ -1545,6 +1691,218 @@ extern "C"
     AXIS2_EXTERN axutil_array_list_t* AXIS2_CALL
     rampart_context_get_custom_tokens(rampart_context_t *rampart_context,
                                         const axutil_env_t *env);
+
+    /**
+     * Get the receiver certificate file name from rampart context.
+     * @param rampart_context Pointer to rampart context struct.
+     * @param env Pointer to environment struct
+     * @returns Receiver certificate file name
+     */
+    AXIS2_EXTERN axis2_char_t *AXIS2_CALL
+    rampart_context_get_receiver_certificate_file(
+        rampart_context_t *rampart_context,
+        const axutil_env_t *env);
+      
+    /**
+     * Get the found_cert_in_shp from rampart context.
+     * @param rampart_context Pointer to rampart context struct.
+     * @param env Pointer to environment struct
+     * @returns axis2_bool_t
+     */
+    AXIS2_EXTERN axis2_bool_t AXIS2_CALL
+    rampart_context_get_found_cert_in_shp(
+        rampart_context_t *rampart_context,
+        const axutil_env_t *env);
+    
+    /**
+     * Set the certificate found status to rampart context.
+     * @param rampart_context Pointer to rampart context struct.
+     * @param env Pointer to environment struct
+     * @param found_cert_in_shp boolean value which specify the certificate found status
+     * @returns status of the operation
+     */
+    AXIS2_EXTERN axis2_status_t AXIS2_CALL
+    rampart_context_set_found_cert_in_shp(
+        rampart_context_t *rampart_context,
+        const axutil_env_t *env,
+        axis2_bool_t found_cert_in_shp);
+    
+    /**
+     * Get the certificate found in shp from rampart context.
+     * @param rampart_context Pointer to rampart context struct.
+     * @param env Pointer to environment struct
+     * @returns oxs_x509_cert_t Client certificate found when processing sec header, otherwise NULL
+     */   
+    AXIS2_EXTERN oxs_x509_cert_t *AXIS2_CALL
+    rampart_context_get_receiver_cert_found_in_shp(
+        rampart_context_t *rampart_context,
+        const axutil_env_t *env);
+    
+    /**
+     * Set the found_cert_in_shp to rampart context.
+     * @param rampart_context Pointer to rampart context struct.
+     * @param env Pointer to environment struct
+     * @param cert pointer to the certficate
+     * @returns status of the operation
+     */    
+    AXIS2_EXTERN axis2_status_t AXIS2_CALL
+    rampart_context_set_receiver_cert_found_in_shp(
+        rampart_context_t *rampart_context,
+        const axutil_env_t *env,
+        oxs_x509_cert_t *cert);
+
+    AXIS2_EXTERN void * AXIS2_CALL
+    rampart_context_get_key_store_buff(
+        rampart_context_t *rampart_context,
+        const axutil_env_t *env);
+
+    AXIS2_EXTERN axis2_status_t AXIS2_CALL
+    rampart_context_set_key_store_buff(
+        rampart_context_t *rampart_context,
+        const axutil_env_t *env,
+        void *key_store_buf,
+        int length);
+
+    /**
+     * Set the function used to store security context token
+     * @param rampart_context Pointer to rampart context struct.
+     * @param env Pointer to environment struct
+     * @param store_fn funtion pointer used to store sct
+     * @returns status of the operation
+     */    
+    AXIS2_EXTERN axis2_status_t AXIS2_CALL
+    rampart_context_set_store_security_context_token_fn(
+        rampart_context_t *rampart_context,
+        const axutil_env_t *env,
+        store_security_context_token_fn store_fn);
+
+    /**
+     * Set the function used to get security context token
+     * @param rampart_context Pointer to rampart context struct.
+     * @param env Pointer to environment struct
+     * @param get_fn funtion pointer used to get stored sct
+     * @returns status of the operation
+     */    
+    AXIS2_EXTERN axis2_status_t AXIS2_CALL
+    rampart_context_set_obtain_security_context_token_fn(
+        rampart_context_t *rampart_context,
+        const axutil_env_t *env,
+        obtain_security_context_token_fn get_fn);
+
+    /**
+     * Set the function used to delete security context token
+     * @param rampart_context Pointer to rampart context struct.
+     * @param env Pointer to environment struct
+     * @param delete_fn funtion pointer used to delete stored sct
+     * @returns status of the operation
+     */    
+    AXIS2_EXTERN axis2_status_t AXIS2_CALL
+    rampart_context_set_delete_security_context_token_fn(
+        rampart_context_t *rampart_context,
+        const axutil_env_t *env,
+        delete_security_context_token_fn delete_fn);
+
+    /**
+     * Set the user parameters used to invoke security context token related funtions
+     * @param rampart_context Pointer to rampart context struct.
+     * @param env Pointer to environment struct
+     * @param user_params pointer to user params
+     * @returns status of the operation
+     */    
+    AXIS2_EXTERN axis2_status_t AXIS2_CALL
+    rampart_context_set_security_context_token_user_params(
+        rampart_context_t *rampart_context,
+        const axutil_env_t *env,
+        void* user_params);
+
+    /**
+     * Set the function used to validate security context token
+     * @param rampart_context Pointer to rampart context struct.
+     * @param env Pointer to environment struct
+     * @param validate_fn funtion pointer used to validate sct
+     * @returns status of the operation
+     */    
+    AXIS2_EXTERN axis2_status_t AXIS2_CALL
+    rampart_context_set_validate_security_context_token_fn(
+        rampart_context_t *rampart_context,
+        const axutil_env_t *env,
+        validate_security_context_token_fn validate_fn);
+
+    /**
+     * Get the function used to store security context token
+     * @param rampart_context Pointer to rampart context struct.
+     * @param env Pointer to environment struct
+     * @returns untion pointer used to store sct
+     */    
+    AXIS2_EXTERN store_security_context_token_fn AXIS2_CALL
+    rampart_context_get_store_security_context_token_fn(
+        rampart_context_t *rampart_context,
+        const axutil_env_t *env);
+
+    /**
+     * Get the function used to get security context token
+     * @param rampart_context Pointer to rampart context struct.
+     * @param env Pointer to environment struct
+     * @returns funtion pointer used to get stored sct
+     */    
+    AXIS2_EXTERN obtain_security_context_token_fn AXIS2_CALL
+    rampart_context_get_obtain_security_context_token_fn(
+        rampart_context_t *rampart_context,
+        const axutil_env_t *env);
+
+    /**
+     * Get the function used to delete security context token
+     * @param rampart_context Pointer to rampart context struct.
+     * @param env Pointer to environment struct
+     * @returns funtion pointer used to delete stored sct
+     */    
+    AXIS2_EXTERN delete_security_context_token_fn AXIS2_CALL
+    rampart_context_get_delete_security_context_token_fn(
+        rampart_context_t *rampart_context,
+        const axutil_env_t *env);
+
+    /**
+     * Get the user parameters used to invoke security context token related funtions
+     * @param rampart_context Pointer to rampart context struct.
+     * @param env Pointer to environment struct
+     * @param user_params pointer to user params
+     * @returns pointer to user parameter.
+     */    
+    AXIS2_EXTERN void* AXIS2_CALL
+    rampart_context_get_security_context_token_user_params(
+        rampart_context_t *rampart_context,
+        const axutil_env_t *env);
+
+    /**
+     * Get the function used to validate security context token
+     * @param rampart_context Pointer to rampart context struct.
+     * @param env Pointer to environment struct
+     * @returns funtion pointer used to validate sct
+     */    
+    AXIS2_EXTERN validate_security_context_token_fn AXIS2_CALL
+    rampart_context_get_validate_security_context_token_fn(
+        rampart_context_t *rampart_context,
+        const axutil_env_t *env);
+
+    /**
+     * check whether different keys are needed for encryption and signature
+     * @param env pointer to environment struct
+     * @param rampart_context rampart context
+     * @return AXIS2_TRUE if different keys are needed. AXIS2_FALSE otherwise.
+     */
+    AXIS2_EXTERN axis2_bool_t AXIS2_CALL
+    rampart_context_is_different_session_key_for_enc_and_sign(
+        const axutil_env_t *env,
+        rampart_context_t *rampart_context);
+
+    AXIS2_EXTERN axis2_status_t AXIS2_CALL
+rampart_context_set_receiver_certificate_file(
+	rampart_context_t *rampart_context,
+	const axutil_env_t *env,
+	axis2_char_t *receiver_certificate_file);
+
+
+    
 #ifdef __cplusplus
 }
 #endif
