@@ -7,5 +7,5 @@ echo "Copying latest module to client_repo"
 cp -r $AXIS2C_HOME/modules/rampart $CLIENT_REPO/modules
 
 #RUN
-./echo http://localhost:9090/axis2/services/sec_echo/echoString $CLIENT_REPO
+./sec_echo http://localhost:9090/axis2/services/sec_echo $CLIENT_REPO
 
