@@ -18,6 +18,8 @@
 #include <trust_sts_client.h>
 #include <axis2_op_client.h>
 #include <openssl_hmac.h>
+#include <oxs_utility.h>
+#include <axiom_util.h>
 
 static void
 trust_sts_client_insert_entropy(
@@ -242,6 +244,7 @@ trust_sts_client_get_svc_client(
     options = axis2_options_create(env);
     axis2_options_set_to(options, env, endpoint_ref);
     axis2_options_set_action(options, env, action);
+    axis2_options_set_xml_parser_reset(options, env, AXIS2_FALSE); 
     if(is_soap11)
     {
         axis2_options_set_soap_action(options, env, axutil_string_create(env, action));
@@ -268,8 +271,9 @@ trust_sts_client_get_svc_client(
     /* Set service client options */
     axis2_svc_client_set_options(svc_client, env, options);
 
-    /* Engage addressing module */
+    /* Engage addressing module and rampart module */
     axis2_svc_client_engage_module(svc_client, env, AXIS2_MODULE_ADDRESSING);
+    axis2_svc_client_engage_module(svc_client, env, RAMPART_RAMPART);
 
     /*set the address version*/
     if(address_version)
@@ -411,7 +415,8 @@ trust_sts_client_request_security_token_using_policy(
     trust_context_t *trust_context,
     neethi_policy_t *issuer_policy, 
     axis2_char_t *address_version, 
-    axis2_bool_t is_soap11)
+    axis2_bool_t is_soap11, 
+    rampart_context_t *rampart_context)
 {
     axis2_status_t status = AXIS2_SUCCESS;
     axiom_node_t *rst_node = NULL;
@@ -454,6 +459,23 @@ trust_sts_client_request_security_token_using_policy(
 
     if (sts_client->svc_client)
     {
+        /* if rampart context is set, we can set it to svc_client. This will be used by 
+         * scripting bindings to specify rampart specific values */
+        if(rampart_context)
+        {
+            axis2_svc_ctx_t *svc_ctx = NULL;
+            axis2_conf_ctx_t *conf_ctx = NULL;
+            axis2_conf_t *conf = NULL;
+            axutil_param_t *security_param = NULL;
+
+            svc_ctx = axis2_svc_client_get_svc_ctx (sts_client->svc_client, env);
+            conf_ctx = axis2_svc_ctx_get_conf_ctx (svc_ctx, env);
+            conf = axis2_conf_ctx_get_conf (conf_ctx, env);
+            security_param = axutil_param_create (
+                env, RAMPART_CONFIGURATION, (void *)rampart_context);
+            axis2_conf_add_param (conf, env, security_param);
+        }
+
 		if(issuer_policy)
 		{
 			status = axis2_svc_client_set_policy(sts_client->svc_client, env, issuer_policy);
@@ -550,7 +572,7 @@ trust_sts_client_insert_entropy(
     }
 
     /*nonce should be created with half the size. size is in bits, have to convert it to bytes*/
-    nonce = rampart_generate_nonce(env, key_size/16);
+    nonce = oxs_util_generate_nonce(env, key_size/16);
     if(!nonce)
     {
         AXIS2_LOG_ERROR(env->log, AXIS2_LOG_SI, "[trust] cannon create nonce with length %d", key_size/16);
@@ -559,7 +581,7 @@ trust_sts_client_insert_entropy(
 
     entropy = trust_entropy_create(env);
     trust_entropy_set_binary_secret(entropy, env, nonce);
-    trust_entropy_set_ns_uri(entropy, env, TRUST_WST_XMLNS_05_02);
+    trust_entropy_set_ns_uri(entropy, env, trust_rst_get_wst_ns_uri(rst, env));
     trust_entropy_set_binary_secret_type(entropy, env, NONCE);
 
     trust_rst_set_key_size(rst, env, key_size);
