@@ -32,27 +32,24 @@
 #include <oxs_derivation.h>
 #include <axis2_key_type.h>
 #include <oxs_derivation.h>
-#include <rampart_sct_provider.h>
+#include <rampart_sct_provider_utility.h>
+#include <axiom_util.h>
 
-
-/*Private functions*/
-
-axis2_status_t AXIS2_CALL
+static axis2_status_t AXIS2_CALL
 rampart_enc_get_nodes_to_encrypt(
     rampart_context_t *rampart_context,
     const axutil_env_t *env,
     axiom_soap_envelope_t *soap_envelope,
     axutil_array_list_t *nodes_to_encrypt)
 {
-
     axis2_status_t status1 = AXIS2_SUCCESS;
     axis2_status_t status2 = AXIS2_SUCCESS;
     
     status1 = rampart_context_get_nodes_to_encrypt(
-                  rampart_context, env, soap_envelope, nodes_to_encrypt);
+        rampart_context, env, soap_envelope, nodes_to_encrypt);
 
     status2 = rampart_context_get_elements_to_encrypt(
-                  rampart_context, env, soap_envelope, nodes_to_encrypt);
+        rampart_context, env, soap_envelope, nodes_to_encrypt);
 
     if(status1 == AXIS2_SUCCESS || status2 == AXIS2_SUCCESS)
     {
@@ -64,14 +61,21 @@ rampart_enc_get_nodes_to_encrypt(
     }
 }
 
-
-/*Public functions*/
+/**
+ * Encrypts the session key using assymmetric encription
+ * @param env pointer to environment struct
+ * @param session_key the session key to be encrypted
+ * @param msg_ctx message context
+ * @param rampart_context the rampart context
+ * @param sec_node The security element
+ * @return AXIS2_SUCCESS on success, else AXIS2_FAILURE
+ */
 AXIS2_EXTERN axis2_status_t AXIS2_CALL
-rampart_enc_encrypt_session_key(const axutil_env_t *env,
+rampart_enc_encrypt_session_key(
+    const axutil_env_t *env,
     oxs_key_t *session_key,
     axis2_msg_ctx_t *msg_ctx,
     rampart_context_t *rampart_context,
-    axiom_soap_envelope_t *soap_envelope,
     axiom_node_t *sec_node,
     axutil_array_list_t *id_list)
 {
@@ -81,35 +85,26 @@ rampart_enc_encrypt_session_key(const axutil_env_t *env,
     axis2_bool_t server_side = AXIS2_FALSE;
     rp_property_t *token = NULL;
     rp_property_type_t token_type;
-    rampart_callback_t *password_callback = NULL;
-    password_callback_fn password_function = NULL;
     axis2_char_t *eki = NULL;
-    void *key_buf = NULL;
-    void *param = NULL;
-    axis2_char_t *certificate_file = NULL;
-    axis2_char_t *password = NULL;
-    axis2_char_t *enc_user = NULL;
-    token = rampart_context_get_token(rampart_context, env,
-                                      AXIS2_TRUE, server_side, AXIS2_FALSE);
+	oxs_x509_cert_t *certificate = NULL; 
+    
+    server_side = axis2_msg_ctx_get_server_side(msg_ctx, env);
+    token = rampart_context_get_token(rampart_context, env, AXIS2_TRUE, server_side, AXIS2_FALSE);
     token_type = rp_property_get_type(token, env);
 
     if(!rampart_context_is_token_type_supported(token_type, env))
     {
-        AXIS2_LOG_ERROR(env->log, AXIS2_LOG_SI,
-                        "[rampart][rampart_encryption] Specified token type not supported.");
+        AXIS2_LOG_ERROR(env->log, AXIS2_LOG_SI, "[rampart]Specified token type not supported.");
         return AXIS2_FAILURE;
     }
     
-
-    /*Get the asymmetric key encryption algorithm*/
+    /* Get the asymmetric key encryption algorithm */
     enc_asym_algo = rampart_context_get_enc_asym_algo(rampart_context, env);
-
-    /*Get encryption key identifier*/
-    /*First we should check whether we include the token in the
-     *message.*/
-
-    if(rampart_context_is_token_include(rampart_context,
-                                        token, token_type, server_side, AXIS2_FALSE, env))
+ 
+    /* Get encryption key identifier. This identifier depends on whether we include the token in 
+     * the message. */
+    if(rampart_context_is_token_include(
+        rampart_context, token, token_type, server_side, AXIS2_FALSE, env))
     {
         eki = RAMPART_STR_DIRECT_REFERENCE;
     }
@@ -117,101 +112,66 @@ rampart_enc_encrypt_session_key(const axutil_env_t *env,
     {
         eki = rampart_context_get_key_identifier(rampart_context, token, env);
     }
+
     if(!eki)
     {
-        AXIS2_LOG_ERROR(env->log, AXIS2_LOG_SI,
-                        "[rampart][rampart_encryption] No mechanism for attaching the certificate info.");
+        AXIS2_LOG_ERROR(env->log, AXIS2_LOG_SI, 
+            "[rampart] No mechanism for attaching the certificate information.");
         return AXIS2_FAILURE;
     }
 
-    /*Create asymmetric encryption context*/
-    asym_ctx = oxs_asym_ctx_create(env);
-    oxs_asym_ctx_set_algorithm(asym_ctx, env, enc_asym_algo);
-
-    /*First check whether the public key is set*/
-    key_buf = rampart_context_get_receiver_certificate(rampart_context, env);
-    if(key_buf)
+    /* Receiver certificate can be in the received message. In that case, we should use it. 
+       If it is not there, then can get from key manager */
+    if(rampart_context_get_found_cert_in_shp(rampart_context, env))
     {
-        axis2_key_type_t type = 0;
-        type = rampart_context_get_receiver_certificate_type(rampart_context, env);
-        if(type == AXIS2_KEY_TYPE_PEM)
-        {
-            oxs_asym_ctx_set_format(asym_ctx, env, OXS_ASYM_CTX_FORMAT_PEM);
-            oxs_asym_ctx_set_pem_buf(asym_ctx, env, (axis2_char_t *)key_buf);
-        }
+        certificate = rampart_context_get_receiver_cert_found_in_shp(rampart_context, env);
     }
-
-    /*Buffer is null load from the file*/
     else
     {
-        certificate_file = rampart_context_get_receiver_certificate_file(
-                               rampart_context, env);
-        oxs_asym_ctx_set_file_name(asym_ctx, env, certificate_file);
-        oxs_asym_ctx_set_format(asym_ctx, env,
-                                oxs_util_get_format_by_file_extension(env, certificate_file));
-
-        /*Get the password to retrieve the key from key store*/
-        password = rampart_context_get_prv_key_password(rampart_context, env);
-
-        if(!password)
-        {
-            enc_user = rampart_context_get_encryption_user(rampart_context, env);
-
-            if(!enc_user)
-            {
-                enc_user = rampart_context_get_user(rampart_context, env);
-            }
-
-            if(enc_user)
-            {
-                password_function = rampart_context_get_pwcb_function(rampart_context, env);
-                if(password_function)
-                {
-                    password = (*password_function)(env, enc_user, param);
-                }
-
-                else
-                {
-                    password_callback = rampart_context_get_password_callback
-                                        (rampart_context, env);
-                    if(!password_callback)
-                    {
-                        AXIS2_LOG_ERROR(env->log, AXIS2_LOG_SI,
-                                        "[rampart][rampart_encryption] Password call back module is not loaded.");
-                        return AXIS2_FAILURE;
-                    }
-                    password = rampart_callback_password(env, password_callback, enc_user);
-                    if(password)
-                    {
-                        oxs_asym_ctx_set_password(asym_ctx, env, password);
-                    }
-                }
-            }
-        }
+        oxs_key_mgr_t *key_mgr = NULL;
+        key_mgr = rampart_context_get_key_mgr(rampart_context, env);
+        certificate = oxs_key_mgr_get_receiver_certificate(key_mgr, env);
     }
-    oxs_asym_ctx_set_operation(asym_ctx, env,
-                               OXS_ASYM_CTX_OPERATION_PUB_ENCRYPT);
+
+    if (!certificate)
+    {
+        AXIS2_LOG_ERROR(env->log, AXIS2_LOG_SI, "[rampart] Receiver certificate cannot be loaded.");
+        return AXIS2_FAILURE;
+    }
+
+    /* Create asymmetric encryption context and populate algorithm, certificate etc. */
+    asym_ctx = oxs_asym_ctx_create(env);
+    oxs_asym_ctx_set_algorithm(asym_ctx, env, enc_asym_algo);
+    oxs_asym_ctx_set_certificate(asym_ctx, env, certificate);
+    oxs_asym_ctx_set_operation(asym_ctx, env,OXS_ASYM_CTX_OPERATION_PUB_ENCRYPT);
     oxs_asym_ctx_set_st_ref_pattern(asym_ctx, env, eki);
 
-    /*Encrypt the session key*/
-    status = oxs_xml_enc_encrypt_key(env, asym_ctx,
-                                     sec_node, session_key, id_list);
+    /* Encrypt the session key */
+    status = oxs_xml_enc_encrypt_key(env, asym_ctx, sec_node, session_key, id_list);
     oxs_asym_ctx_free(asym_ctx, env);
     asym_ctx = NULL;
     
-    if(AXIS2_FAILURE == status)
+    if(status != AXIS2_SUCCESS)
     {
-        AXIS2_LOG_ERROR(env->log, AXIS2_LOG_SI,
-                        "[rampart][rampart_encryption] Session key encryption failed.");
+        AXIS2_LOG_ERROR(env->log, AXIS2_LOG_SI, "[rampart] Session key encryption failed.");
         return AXIS2_FAILURE;
-    }else{
-	    return AXIS2_SUCCESS;
     }
 
+    return AXIS2_SUCCESS;
 }
 
+/**
+ * Encrypt the message using derived keys. Uses symmetric encryption
+ * @param env pointer to environment struct
+ * @param msg_ctx message context
+ * @param rampart_context rampart context
+ * @param soap_envelope the SOAP envelope
+ * @param sec_node The security element
+ * @return AXIS2_SUCCESS on success, else AXIS2_FAILURE
+ */
 AXIS2_EXTERN axis2_status_t AXIS2_CALL
-rampart_enc_dk_encrypt_message(const axutil_env_t *env,
+rampart_enc_dk_encrypt_message(
+    const axutil_env_t *env,
     axis2_msg_ctx_t *msg_ctx,
     rampart_context_t *rampart_context,
     axiom_soap_envelope_t *soap_envelope,
@@ -230,40 +190,49 @@ rampart_enc_dk_encrypt_message(const axutil_env_t *env,
     axiom_node_t *sig_node = NULL;
     axiom_node_t *data_ref_list_node = NULL;
     axis2_bool_t use_derived_keys = AXIS2_TRUE;
+    axis2_char_t *derived_key_version = NULL;
     axis2_bool_t server_side = AXIS2_FALSE;
     rp_property_t *token = NULL;
     rp_property_type_t token_type;
-
+    rampart_saml_token_t *saml = NULL;
     oxs_key_t *derived_key = NULL;
+    axiom_soap_body_t *body = NULL;
+    axiom_node_t *body_node = NULL;
+    axiom_node_t *body_child_node = NULL;
 
     axis2_bool_t signature_protection = AXIS2_FALSE;
     int i = 0;
     int j = 0;
 
-    /*Get nodes to be encrypted*/
+    body = axiom_soap_envelope_get_body(soap_envelope, env);
+    body_node = axiom_soap_body_get_base_node(body, env);
+    body_child_node = axiom_node_get_first_element(body_node, env);
+
+    /* Get nodes to be encrypted */
     nodes_to_encrypt = axutil_array_list_create(env, 0);
     status = rampart_enc_get_nodes_to_encrypt(
-                 rampart_context, env, soap_envelope, nodes_to_encrypt);
+        rampart_context, env, soap_envelope, nodes_to_encrypt);
 
     if(status != AXIS2_SUCCESS)
     {
-        AXIS2_LOG_ERROR(env->log, AXIS2_LOG_SI,
-                        "[rampart][rampart_encryption] Error occured in Adding Encrypted parts..");
+        AXIS2_LOG_ERROR(env->log, AXIS2_LOG_SI, 
+            "[rampart]Error occured in Adding Encrypted parts.");
         axutil_array_list_free(nodes_to_encrypt, env);
         nodes_to_encrypt = NULL;
         return AXIS2_FAILURE;
     }
     
-    /*If the sp:EncryptSignature is ON  &&  We sign before the encryption, we need to add signature node too. */
-    signature_protection = rampart_context_is_encrypt_signature(
-                               rampart_context, env);
+    /* If the sp:EncryptSignature is ON  &&  We sign before the encryption, 
+     * we need to add signature node too. */
+    signature_protection = rampart_context_is_encrypt_signature(rampart_context, env);
 
+    /* if nothing to encrypt, then we can return successfully */
     if((axutil_array_list_size(nodes_to_encrypt, env)==0))
     {
         if(!signature_protection)
         {
             AXIS2_LOG_DEBUG(env->log, AXIS2_LOG_SI,
-                           "[rampart][rampart_encryption] No parts specified or specified parts can't be found for encryprion.");
+                "[rampart]No parts specified or specified parts can't be found for encryprion.");
 			axutil_array_list_free(nodes_to_encrypt, env);
 			nodes_to_encrypt = NULL;
             return AXIS2_SUCCESS;
@@ -320,7 +289,23 @@ rampart_enc_dk_encrypt_message(const axutil_env_t *env,
     token = rampart_context_get_token(rampart_context, env, AXIS2_TRUE, server_side, AXIS2_FALSE);
     token_type = rp_property_get_type(token, env);
     use_derived_keys = rampart_context_check_is_derived_keys (env, token);
+    derived_key_version = rampart_context_get_derived_key_version(env, token);
 
+    if(token_type == RP_PROPERTY_SAML_TOKEN)
+    {
+        /* We need to obtain the saml here because it is used in many parts of the code*/
+        saml = rampart_context_get_saml_token(rampart_context, env, RAMPART_ST_TYPE_ENCRYPTION_TOKEN);
+		if (!saml)
+		{
+			saml = rampart_context_get_saml_token(rampart_context, env, RAMPART_ST_TYPE_PROTECTION_TOKEN);
+		}
+        if (!saml)
+        {
+            AXIS2_LOG_ERROR(env->log, AXIS2_LOG_SI,
+                            "[rampart][rampart_encryption] SAML not set.");                
+            return AXIS2_FAILURE;
+        }
+    }
     session_key = rampart_context_get_encryption_session_key(rampart_context, env);
     if(!session_key)
     {
@@ -330,7 +315,7 @@ rampart_enc_dk_encrypt_message(const axutil_env_t *env,
         {
             oxs_buffer_t *key_buf = NULL;
             session_key = oxs_key_create(env);
-            key_buf = sct_provider_get_secret(env, token, server_side, AXIS2_TRUE, rampart_context, msg_ctx);
+            key_buf = sct_provider_get_secret(env, token, AXIS2_TRUE, rampart_context, msg_ctx);
             if(!key_buf)
             {
                 AXIS2_LOG_ERROR(env->log, AXIS2_LOG_SI,
@@ -343,10 +328,21 @@ rampart_enc_dk_encrypt_message(const axutil_env_t *env,
                    oxs_buffer_get_size(key_buf, env), OXS_KEY_USAGE_NONE);
             rampart_context_set_encryption_session_key(rampart_context, env, session_key);
         }
+        else if(token_type == RP_PROPERTY_SAML_TOKEN)
+        {			
+			session_key = rampart_saml_token_get_session_key(saml, env);
+			if (!session_key)
+			{
+				AXIS2_LOG_ERROR(env->log, AXIS2_LOG_SI,
+                                "[rampart][rampart_encryption] SAML session key not specified.");                
+                return AXIS2_FAILURE;
+			}
+            rampart_context_set_encryption_session_key(rampart_context, env, session_key);
+        }
         else
         {
             axis2_char_t *token_id = NULL;
-            token_id = rampart_context_get_encryption_token_id(rampart_context, env);
+            token_id = rampart_context_get_encryption_token_id(rampart_context, env, msg_ctx);
             if(token_id)
             {
                 session_key = rampart_context_get_key(rampart_context, env, token_id);
@@ -434,12 +430,33 @@ rampart_enc_dk_encrypt_message(const axutil_env_t *env,
                                                 token, token_type, server_side, AXIS2_FALSE, env))
                 {
                     /*set the AttachedReference to key_reference_node*/
-                    key_reference_node = sct_provider_get_attached_reference(env, token, server_side, AXIS2_TRUE, rampart_context, msg_ctx);
+                    key_reference_node = sct_provider_get_attached_reference(env, token, AXIS2_TRUE, rampart_context, msg_ctx);
                 }
                 else
                 {
                     /*get the unattachedReference and set to key_reference_node*/
-                    key_reference_node = sct_provider_get_unattached_reference(env, token, server_side, AXIS2_TRUE, rampart_context, msg_ctx);
+                    key_reference_node = sct_provider_get_unattached_reference(env, token, AXIS2_TRUE, rampart_context, msg_ctx);
+                }
+            }
+            else if (token_type == RP_PROPERTY_SAML_TOKEN)
+            {
+                if(rampart_context_is_token_include(rampart_context,
+                                                token, token_type, server_side, AXIS2_FALSE, env))
+                {
+					axiom_node_t *assertion = NULL;
+                    /*set the AttachedReference to key_reference_node*/
+                    key_reference_node = rampart_saml_token_get_str(saml, env);						
+					if (!key_reference_node)
+					{
+						assertion = rampart_saml_token_get_assertion(saml, env);
+						key_reference_node = oxs_saml_token_build_key_identifier_reference_local(env, NULL, assertion);
+					}
+                }
+                else
+                {                    
+                    AXIS2_LOG_ERROR(env->log, AXIS2_LOG_SI,
+                                "[rampart][rampart_encryption] SAML session key not specified.");                
+                    return AXIS2_FAILURE;                    
                 }
             }
             else
@@ -469,8 +486,16 @@ rampart_enc_dk_encrypt_message(const axutil_env_t *env,
  
         if(parent_of_node_to_enc || enc_data_id)
         {
+            axis2_char_t *enc_type = OXS_TYPE_ENC_ELEMENT;
+
+            if(body_child_node == node_to_enc)
+            {
+                /* we have to use #Content for body encryption */
+                enc_type = OXS_TYPE_ENC_CONTENT;
+            }
+
             enc_data_node = oxs_token_build_encrypted_data_element(env,
-                            parent_of_node_to_enc, OXS_TYPE_ENC_ELEMENT, enc_data_id );
+                            parent_of_node_to_enc, enc_type, enc_data_id );
             status = oxs_xml_enc_encrypt_node(env, enc_ctx,
                                                   node_to_enc, &enc_data_node, key_reference_node);
             /*Add Ids to the list. We will create reference list*/
@@ -510,9 +535,9 @@ rampart_enc_dk_encrypt_message(const axutil_env_t *env,
             axiom_node_t *security_context_token_node = NULL;
             /*include the security context token*/
             security_context_token_node = oxs_axiom_get_node_by_local_name(env, sec_node,  OXS_NODE_SECURITY_CONTEXT_TOKEN);
-            if((!security_context_token_node) || (is_different_session_key_for_encryption_and_signing(env, rampart_context)))
+            if((!security_context_token_node) || (rampart_context_is_different_session_key_for_enc_and_sign(env, rampart_context)))
             {
-                security_context_token_node = sct_provider_get_token(env, token, server_side, AXIS2_TRUE, rampart_context, msg_ctx);
+                security_context_token_node = sct_provider_get_token(env, token, AXIS2_TRUE, rampart_context, msg_ctx);
                 if(!security_context_token_node)
                 {
                     AXIS2_LOG_ERROR(env->log, AXIS2_LOG_SI,
@@ -531,6 +556,32 @@ rampart_enc_dk_encrypt_message(const axutil_env_t *env,
             }
         }
     }
+    else if (token_type == RP_PROPERTY_SAML_TOKEN)
+    {
+        if(rampart_context_is_token_include(rampart_context,
+                                        token, token_type, server_side, AXIS2_FALSE, env))
+        {
+            axiom_node_t *assertion = NULL;
+            /*include the security context token*/            
+            if (!rampart_saml_token_is_added_to_header(saml, env))
+                assertion = rampart_saml_token_get_assertion(saml, env);
+                if(!assertion)
+                {
+                    AXIS2_LOG_ERROR(env->log, AXIS2_LOG_SI,
+                                "[rampart][rampart_encryption] Cannot get SAML token");
+			        for(j=0 ; j < axutil_array_list_size(id_list, env); j++)
+			        {
+				        axis2_char_t *id = NULL;
+				        id = (axis2_char_t *)axutil_array_list_get(id_list, env, j);
+				        AXIS2_FREE(env->allocator, id);
+			        }
+			        axutil_array_list_free(id_list, env);
+			        id_list = NULL;
+                    return AXIS2_FAILURE;
+                }
+                axiom_node_add_child(sec_node, env, assertion);
+        }        
+    }
     else
     {
         /* If not done already, Encrypt the session key using the Public Key of the recipient*/
@@ -542,7 +593,7 @@ rampart_enc_dk_encrypt_message(const axutil_env_t *env,
             if(!encrypted_key_node)
             {
                 /*Create EncryptedKey element*/
-                status = rampart_enc_encrypt_session_key(env, session_key, msg_ctx, rampart_context, soap_envelope, sec_node, NULL );
+                status = rampart_enc_encrypt_session_key(env, session_key, msg_ctx, rampart_context, sec_node, NULL );
                 if(AXIS2_FAILURE == status)
                 {
                     AXIS2_LOG_ERROR(env->log, AXIS2_LOG_SI,
@@ -607,14 +658,14 @@ rampart_enc_dk_encrypt_message(const axutil_env_t *env,
                                                     token, token_type, server_side, AXIS2_FALSE, env))
                 {
                     /*set the AttachedReference to key_reference_node*/
-                    key_reference_node = sct_provider_get_attached_reference(env, token, server_side, AXIS2_TRUE, rampart_context, msg_ctx);
+                    key_reference_node = sct_provider_get_attached_reference(env, token, AXIS2_TRUE, rampart_context, msg_ctx);
                 }
                 else
                 {
                     /*get the unattachedReference and set to key_reference_node*/
-                    key_reference_node = sct_provider_get_unattached_reference(env, token, server_side, AXIS2_TRUE, rampart_context, msg_ctx);
+                    key_reference_node = sct_provider_get_unattached_reference(env, token, AXIS2_TRUE, rampart_context, msg_ctx);
                 }
-                dk_node = oxs_derivation_build_derived_key_token_with_stre(env, dk, sec_node, key_reference_node);
+                dk_node = oxs_derivation_build_derived_key_token_with_stre(env, dk, sec_node, key_reference_node, derived_key_version);
             }
             else
             {
@@ -626,11 +677,11 @@ rampart_enc_dk_encrypt_message(const axutil_env_t *env,
                     key_reference_node = oxs_token_build_security_token_reference_element(env, NULL); 
                     identifier_token = oxs_token_build_key_identifier_element(env, key_reference_node, 
                                         OXS_ENCODING_BASE64BINARY, OXS_X509_ENCRYPTED_KEY_SHA1, encrypted_key_hash);
-                    dk_node = oxs_derivation_build_derived_key_token_with_stre(env, dk, sec_node, key_reference_node);
+                    dk_node = oxs_derivation_build_derived_key_token_with_stre(env, dk, sec_node, key_reference_node, derived_key_version);
                 }
                 else
                 {
-                    dk_node = oxs_derivation_build_derived_key_token(env, dk, sec_node, asym_key_id, OXS_WSS_11_VALUE_TYPE_ENCRYPTED_KEY);
+                    dk_node = oxs_derivation_build_derived_key_token(env, dk, sec_node, asym_key_id, OXS_WSS_11_VALUE_TYPE_ENCRYPTED_KEY, derived_key_version);
                 }
             }
 
@@ -654,7 +705,7 @@ rampart_enc_dk_encrypt_message(const axutil_env_t *env,
 		axis2_char_t *id = NULL;
         axis2_char_t* mod_id = NULL;
 		id = (axis2_char_t *)axutil_array_list_get(id_list, env, j);
-        mod_id = axutil_stracat(env, "#",id);
+        mod_id = axutil_stracat(env, OXS_LOCAL_REFERENCE_PREFIX,id);
         oxs_token_build_data_reference_element(env, data_ref_list_node, mod_id);
         /*if x509 is used and no-derived keys, then we have to modify security token reference*/
         if((token_type == RP_PROPERTY_X509_TOKEN) && (!use_derived_keys) && (asym_key_id))
@@ -672,7 +723,7 @@ rampart_enc_dk_encrypt_message(const axutil_env_t *env,
             reference_node = axiom_node_detach(reference_node, env);
             axiom_node_free_tree(reference_node, env);
             
-            id_ref = axutil_stracat(env, "#",asym_key_id);
+            id_ref = axutil_stracat(env, OXS_LOCAL_REFERENCE_PREFIX,asym_key_id);
             reference_node = oxs_token_build_reference_element(env, str_node,
                                 id_ref, OXS_WSS_11_VALUE_TYPE_ENCRYPTED_KEY);
 
@@ -713,6 +764,13 @@ rampart_enc_encrypt_message(
     int i = 0;
     axis2_bool_t signature_protection = AXIS2_FALSE;
     axiom_node_t *sig_node = NULL;
+    axiom_soap_body_t *body = NULL;
+    axiom_node_t *body_node = NULL;
+    axiom_node_t *body_child_node = NULL;
+
+    body = axiom_soap_envelope_get_body(soap_envelope, env);
+    body_node = axiom_soap_body_get_base_node(body, env);
+    body_child_node = axiom_node_get_first_element(body_node, env);
 
 
     /*Get nodes to be encrypted*/
@@ -865,8 +923,16 @@ rampart_enc_encrypt_message(
 
         if(parent_of_node_to_enc || id)
         {
+            axis2_char_t *enc_type = OXS_TYPE_ENC_ELEMENT;
+
+            if(body_child_node == node_to_enc)
+            {
+                /* we have to use #Content for body encryption */
+                enc_type = OXS_TYPE_ENC_CONTENT;
+            }
+
             enc_data_node = oxs_token_build_encrypted_data_element(env,
-                            parent_of_node_to_enc, OXS_TYPE_ENC_ELEMENT, id );
+                            parent_of_node_to_enc, enc_type, id );
             enc_status = oxs_xml_enc_encrypt_node(env, enc_ctx,
                                                   node_to_enc, &enc_data_node, NULL); 
             axutil_array_list_add(id_list, env, id);
@@ -889,7 +955,7 @@ rampart_enc_encrypt_message(
     nodes_to_encrypt = NULL;
 
     /*We need to encrypt the session key.*/
-    status = rampart_enc_encrypt_session_key(env, session_key, msg_ctx, rampart_context, soap_envelope, sec_node, id_list);
+    status = rampart_enc_encrypt_session_key(env, session_key, msg_ctx, rampart_context, sec_node, id_list);
     if(AXIS2_FAILURE == status){
         return AXIS2_FAILURE;
     }
@@ -974,7 +1040,7 @@ rampart_enc_add_key_info(
             if(str_node)
             {
                 axis2_char_t *key_id_ref = NULL;
-                key_id_ref = axutil_stracat(env, "#",key_id);
+                key_id_ref = axutil_stracat(env, OXS_LOCAL_REFERENCE_PREFIX,key_id);
                 reference_node = oxs_token_build_reference_element(
                                      env, str_node, key_id_ref, NULL);
                 AXIS2_FREE(env->allocator, key_id_ref);
@@ -1041,12 +1107,14 @@ rampart_enc_encrypt_signature(
     axiom_node_t *temp_node = NULL;
     axiom_node_t *node_to_move = NULL;
     axis2_bool_t use_derived_keys = AXIS2_TRUE;
+    axis2_char_t *derived_key_version = NULL;
     axis2_bool_t server_side = AXIS2_FALSE;
     rp_property_t *token = NULL;
     rp_property_type_t token_type;
     axis2_status_t status = AXIS2_FAILURE;
     axiom_node_t *key_reference_node = NULL;
     axiom_node_t *key_reference_for_encrypted_data = NULL;
+    rampart_saml_token_t *saml = NULL;
 
     session_key = rampart_context_get_encryption_session_key(rampart_context, env);
 
@@ -1077,12 +1145,39 @@ rampart_enc_encrypt_signature(
                                         token, token_type, server_side, AXIS2_FALSE, env))
         {
             /*set the AttachedReference to key_reference_node*/
-            key_reference_node = sct_provider_get_attached_reference(env, token, server_side, AXIS2_TRUE, rampart_context, msg_ctx);
+            key_reference_node = sct_provider_get_attached_reference(env, token, AXIS2_TRUE, rampart_context, msg_ctx);
         }
         else
         {
             /*get the unattachedReference and set to key_reference_node*/
-            key_reference_node = sct_provider_get_unattached_reference(env, token, server_side, AXIS2_TRUE, rampart_context, msg_ctx);
+            key_reference_node = sct_provider_get_unattached_reference(env, token, AXIS2_TRUE, rampart_context, msg_ctx);
+        }
+    }
+    else if(token_type == RP_PROPERTY_SAML_TOKEN)
+    {
+        saml = rampart_context_get_saml_token(rampart_context, env, RAMPART_ST_TYPE_ENCRYPTION_TOKEN);
+		if (!saml)
+		{
+			saml = rampart_context_get_saml_token(rampart_context, env, RAMPART_ST_TYPE_PROTECTION_TOKEN);
+		}
+        if (!saml)
+        {
+            AXIS2_LOG_ERROR(env->log, AXIS2_LOG_SI,
+                            "[rampart][rampart_encryption] SAML not set.");                
+            return AXIS2_FAILURE;
+        }
+        if(rampart_context_is_token_include(rampart_context,
+                                        token, token_type, server_side, AXIS2_FALSE, env))
+        {
+            /*set the AttachedReference to key_reference_node*/
+            key_reference_node = rampart_saml_token_get_str(saml, env);
+        }
+        else
+        {
+            /*get the unattachedReference and set to key_reference_node*/
+            AXIS2_LOG_ERROR(env->log, AXIS2_LOG_SI,
+                    "[rampart][rampart_encryption] SAML not set.");                
+            return AXIS2_FAILURE;
         }
     }
     else
@@ -1113,6 +1208,7 @@ rampart_enc_encrypt_signature(
 
     /*We need to take the decision whether to use derived keys or not*/
     use_derived_keys = rampart_context_check_is_derived_keys (env, token);
+    derived_key_version = rampart_context_get_derived_key_version(env, token);
     if(AXIS2_TRUE == use_derived_keys)
     {
         /*Derive a new key*/
@@ -1154,7 +1250,8 @@ rampart_enc_encrypt_signature(
     }
     else if((rampart_context_get_binding_type(rampart_context,env)) == RP_PROPERTY_SYMMETRIC_BINDING)
     {
-        if((AXIS2_TRUE == use_derived_keys) || (token_type == RP_PROPERTY_SECURITY_CONTEXT_TOKEN) || (server_side))
+        if((AXIS2_TRUE == use_derived_keys) || (token_type == RP_PROPERTY_SECURITY_CONTEXT_TOKEN) || (server_side) || 
+            (token_type == RP_PROPERTY_SAML_TOKEN))
         {
             /*We need to create a new reference list and then attach it before the EncryptedData(signature)*/
             axiom_node_t *ref_list_node = NULL;
@@ -1180,7 +1277,7 @@ rampart_enc_encrypt_signature(
                 axis2_char_t *mod_id = NULL;
 
                 /*We need to prepend # to the id in the list to create the reference*/
-                mod_id = axutil_stracat(env, "#",id);
+                mod_id = axutil_stracat(env, OXS_LOCAL_REFERENCE_PREFIX,id);
                 data_ref_node = oxs_token_build_data_reference_element(env, ref_list_node, mod_id);
 
             }
@@ -1215,16 +1312,16 @@ rampart_enc_encrypt_signature(
     /*If we have used a derrived key, we need to attach it to the Securuty Header*/
     if(AXIS2_TRUE == use_derived_keys)
     {
-        if((token_type == RP_PROPERTY_SECURITY_CONTEXT_TOKEN) || 
+        if((token_type == RP_PROPERTY_SECURITY_CONTEXT_TOKEN) || token_type == RP_PROPERTY_SAML_TOKEN ||
             (server_side && (rampart_context_get_binding_type(rampart_context,env) == RP_PROPERTY_SYMMETRIC_BINDING)))
         {
-            oxs_derivation_build_derived_key_token_with_stre(env, derived_key, sec_node, key_reference_node);
+            oxs_derivation_build_derived_key_token_with_stre(env, derived_key, sec_node, key_reference_node, derived_key_version);
         }
         else
         {
             axis2_char_t *asym_key_id = NULL;
             asym_key_id = oxs_axiom_get_attribute_value_of_node_by_name(env, encrypted_key_node, OXS_ATTR_ID, NULL);
-            oxs_derivation_build_derived_key_token(env, derived_key, sec_node, asym_key_id, OXS_WSS_11_VALUE_TYPE_ENCRYPTED_KEY);  
+            oxs_derivation_build_derived_key_token(env, derived_key, sec_node, asym_key_id, OXS_WSS_11_VALUE_TYPE_ENCRYPTED_KEY, derived_key_version);  
         }
 		/*now we can free the derived key*/
 		oxs_key_free(derived_key, env);
