@@ -41,8 +41,9 @@
 #include <rampart_token_builder.h>
 #include <rampart_util.h>
 #include <rampart_sec_processed_result.h>
-#include <rampart_sct_provider.h>
+#include <rampart_sct_provider_utility.h>
 #include <rampart_saml_token.h>
+#include <axiom_util.h>
 
 /*Private functions*/
 
@@ -67,68 +68,6 @@ rampart_sig_endorse_sign(
     axiom_soap_envelope_t *soap_envelope,
     axiom_node_t *sec_node);
 
-
-oxs_x509_cert_t *AXIS2_CALL
-rampart_sig_get_cert(const axutil_env_t *env,
-                     rampart_context_t *rampart_context)
-{
-    void *key_buf = NULL;
-    axis2_key_type_t type = 0;
-    oxs_x509_cert_t *cert = NULL;
-    axis2_char_t *certificate_file = NULL;
-
-    key_buf = rampart_context_get_certificate(rampart_context, env);
-    if(key_buf)
-    {
-        type = rampart_context_get_certificate_type(rampart_context, env);
-        if(type == AXIS2_KEY_TYPE_PEM)
-        {
-            cert = oxs_key_mgr_load_x509_cert_from_string(env,
-                    (axis2_char_t *)key_buf);
-            if(!cert)
-            {
-                AXIS2_LOG_ERROR(env->log, AXIS2_LOG_SI,
-                                "[rampart][rampart_signature] Certificate cannot be loaded from the buffer.");
-                return NULL;
-            }
-            else
-            {
-                return cert;
-            }
-        }
-        else
-        {
-            AXIS2_LOG_ERROR(env->log, AXIS2_LOG_SI,
-                            "[rampart][rampart_signature] Key file type unknown.");
-            return NULL;
-        }
-    }
-    else
-    {
-        certificate_file = rampart_context_get_certificate_file(rampart_context, env);
-        if(certificate_file)
-        {
-            cert = oxs_key_mgr_load_x509_cert_from_pem_file(env, certificate_file);
-            if(!cert)
-            {
-                AXIS2_LOG_ERROR(env->log, AXIS2_LOG_SI,
-                                "[rampart][rampart_signature] Certificate cannot be loaded from the file.");
-                return NULL;
-            }
-            else
-            {
-                return cert;
-            }
-        }
-        else
-        {
-            AXIS2_LOG_ERROR(env->log, AXIS2_LOG_SI,
-                            "[rampart][rampart_signature] Public key certificate file is not specified.");
-            return NULL;
-        }
-    }
-}
-
 axis2_status_t AXIS2_CALL
 rampart_sig_prepare_key_info_for_sym_binding(const axutil_env_t *env,
                 rampart_context_t *rampart_context,
@@ -157,7 +96,7 @@ rampart_sig_prepare_key_info_for_sym_binding(const axutil_env_t *env,
         /*Session key in use. Which is encrypted and hidden in the EncryptedKey with Id=encrypted_key_id*/
         key_id = encrypted_key_id;
         value_type = OXS_WSS_11_VALUE_TYPE_ENCRYPTED_KEY;
-        id_ref = axutil_stracat(env, "#",key_id);
+        id_ref = axutil_stracat(env, OXS_LOCAL_REFERENCE_PREFIX,key_id);
     }else{
         /*Derived Keys in use.*/
         key_id = oxs_key_get_name(key, env);
@@ -181,12 +120,12 @@ rampart_sig_prepare_key_info_for_asym_binding(const axutil_env_t *env,
 				axis2_bool_t is_direct_reference)
 {
     axiom_node_t *key_info_node = NULL;
+	oxs_key_mgr_t *key_mgr = NULL;
     /*axis2_bool_t is_direct_reference = AXIS2_TRUE;*/
     axis2_status_t status = AXIS2_FAILURE;
 
     /*Now we must build the Key Info element*/
-    key_info_node = oxs_token_build_key_info_element(env, sig_node);
-    
+    key_info_node = oxs_token_build_key_info_element(env, sig_node);    
     if(is_direct_reference)
     {
         axiom_node_t *str_node = NULL;
@@ -202,7 +141,7 @@ rampart_sig_prepare_key_info_for_asym_binding(const axutil_env_t *env,
                             "[rampart][rampart_signature] Security Token element creation failed in Direct reference.");
             return AXIS2_FAILURE;
         }
-        cert_id_ref = axutil_stracat(env, "#",cert_id);
+        cert_id_ref = axutil_stracat(env, OXS_LOCAL_REFERENCE_PREFIX,cert_id);
         reference_node = oxs_token_build_reference_element(
                              env, str_node, cert_id_ref, OXS_VALUE_X509V3);
         AXIS2_FREE(env->allocator, cert_id_ref);
@@ -217,8 +156,9 @@ rampart_sig_prepare_key_info_for_asym_binding(const axutil_env_t *env,
     else
     {
         oxs_x509_cert_t *cert = NULL;
-        
-        cert = rampart_sig_get_cert(env, rampart_context);
+        key_mgr = rampart_context_get_key_mgr(rampart_context, env);
+
+        cert = oxs_key_mgr_get_certificate(key_mgr, env);
         if(!cert)
         {
             AXIS2_LOG_ERROR(env->log, AXIS2_LOG_SI,
@@ -240,6 +180,11 @@ rampart_sig_prepare_key_info_for_asym_binding(const axutil_env_t *env,
             status = rampart_token_build_security_token_reference(
                          env, key_info_node, cert, RTBP_KEY_IDENTIFIER);
         }
+        else if(axutil_strcmp(eki, RAMPART_STR_THUMB_PRINT) == 0)
+        {
+            status = rampart_token_build_security_token_reference(
+                        env, key_info_node, cert, RTBP_THUMBPRINT);
+        }
         else
         {
             AXIS2_LOG_ERROR(env->log, AXIS2_LOG_SI,
@@ -289,7 +234,7 @@ rampart_sig_pack_for_sym(const axutil_env_t *env,
         {
             oxs_buffer_t *key_buf = NULL;
             session_key = oxs_key_create(env);
-            key_buf = sct_provider_get_secret(env, token, server_side, AXIS2_FALSE, rampart_context, msg_ctx);
+            key_buf = sct_provider_get_secret(env, token, AXIS2_FALSE, rampart_context, msg_ctx);
             if(!key_buf)
             {
                 AXIS2_LOG_ERROR(env->log, AXIS2_LOG_SI,
@@ -301,15 +246,32 @@ rampart_sig_pack_for_sym(const axutil_env_t *env,
                    oxs_buffer_get_data(key_buf, env), "for-algo",
                    oxs_buffer_get_size(key_buf, env), OXS_KEY_USAGE_NONE);
             rampart_context_set_signature_session_key(rampart_context, env, session_key);
+        }
+		else if(token_type == RP_PROPERTY_SAML_TOKEN)
+        {
+			rampart_saml_token_t *saml = NULL;
+			saml = rampart_context_get_saml_token(rampart_context, env, RAMPART_ST_TYPE_SIGNATURE_TOKEN);
+			if (!saml)
+			{
+				saml = rampart_context_get_saml_token(rampart_context, env, RAMPART_ST_TYPE_PROTECTION_TOKEN);
+			}
+			session_key = rampart_saml_token_get_session_key(saml, env);
+			if (!session_key)
+			{
+				AXIS2_LOG_ERROR(env->log, AXIS2_LOG_SI,
+                                "[rampart][rampart_signature]Session key not specified.");                
+                return AXIS2_FAILURE;
+			}
+			rampart_context_set_signature_session_key(rampart_context, env, session_key);
         }
         else
         {
             axis2_char_t *token_id = NULL;
-            token_id = rampart_context_get_signature_token_id(rampart_context, env);
+            token_id = rampart_context_get_signature_token_id(rampart_context, env, msg_ctx);
             if(token_id)
             {
                 int key_usage = OXS_KEY_USAGE_SESSION;
-                if(is_different_session_key_for_encryption_and_signing(env, rampart_context))
+                if(rampart_context_is_different_session_key_for_enc_and_sign(env, rampart_context))
                     key_usage = OXS_KEY_USAGE_SIGNATURE_SESSION;
 
                 session_key = rampart_context_get_key(rampart_context, env, token_id);
@@ -355,105 +317,17 @@ rampart_sig_pack_for_asym(const axutil_env_t *env,
 		     oxs_sign_ctx_t *sign_ctx)
 {
     openssl_pkey_t *prvkey = NULL;
-    axis2_char_t *prv_key_file = NULL;
-    axis2_char_t *password = NULL;
-    axis2_char_t *enc_user = NULL;
+    oxs_key_mgr_t *key_mgr = NULL;
     axis2_char_t *asym_sig_algo = NULL;
-    password_callback_fn password_function = NULL;
-    rampart_callback_t *password_callback = NULL;
-    void *key_buf = NULL;
-    void *param = NULL;
+    
+	key_mgr = rampart_context_get_key_mgr(rampart_context, env);
+    prvkey = oxs_key_mgr_get_prv_key(key_mgr, env);
 
- /*First check whether the private key is set*/
-    key_buf = rampart_context_get_prv_key(rampart_context, env);
-    if(key_buf)
+	if (!prvkey)
     {
-        axis2_key_type_t type = 0;
-        type = rampart_context_get_prv_key_type(rampart_context, env);
-        if(type == AXIS2_KEY_TYPE_PEM)
-        {
-            prvkey = oxs_key_mgr_load_private_key_from_string(
-                         env, (axis2_char_t *)key_buf, NULL);
-            if(!prvkey)
-            {
-                AXIS2_LOG_ERROR(env->log, AXIS2_LOG_SI,
-                                "[rampart][rampart_signature] Can't load the key from buffer");
-                return AXIS2_FAILURE;
-            }
-        }
-    }else{  /*Buffer is null load from the file*/
-        prv_key_file = rampart_context_get_private_key_file(
-                           rampart_context, env);
-        if(!prv_key_file)
-        {
-            AXIS2_LOG_ERROR(env->log, AXIS2_LOG_SI,
-                            "[rampart][rampart_signature]Private Key file is not specified.");
-            return AXIS2_FAILURE;
-        }
-
-        /*Get the password to retrieve the key from key store*/
-        password = rampart_context_get_prv_key_password(rampart_context, env);
-
-        if(!password)
-        {
-            enc_user = rampart_context_get_encryption_user(rampart_context, env);
-
-            if(!enc_user)
-            {
-                enc_user = rampart_context_get_user(rampart_context, env);
-            }
-
-            if(enc_user)
-            {
-                password_function = rampart_context_get_pwcb_function(rampart_context, env);
-                if(password_function)
-                {
-                    password = (*password_function)(env, enc_user, param);
-                }
-                else
-                {
-                    password_callback = rampart_context_get_password_callback(
-                                            rampart_context, env);
-                    if(!password_callback)
-                    {
-                        AXIS2_LOG_ERROR(env->log, AXIS2_LOG_SI,
-                                        "[rampart][rampart_signature] Password call back module is not loaded.");
-                        return AXIS2_FAILURE;
-                    }
-                    password = rampart_callback_password(env, password_callback, enc_user);
-                }
-            }
-        }
-        if(oxs_util_get_format_by_file_extension(env, prv_key_file) ==
-                OXS_ASYM_CTX_FORMAT_PKCS12)
-        {
-            oxs_x509_cert_t *c = NULL;
-            if((oxs_key_mgr_read_pkcs12_key_store(env, prv_key_file,
-                                                  password, &c, &prvkey)==AXIS2_FAILURE) || !prvkey)
-            {
-                AXIS2_LOG_ERROR(env->log, AXIS2_LOG_SI,
-                                "[rampart][rampart_signature] Cannot load the private key from pfx file.");
-                return AXIS2_FAILURE;
-            }
-        }
-        else if(oxs_util_get_format_by_file_extension(env, prv_key_file)
-                ==OXS_ASYM_CTX_FORMAT_PEM)
-        {
-            prvkey = oxs_key_mgr_load_private_key_from_pem_file(
-                         env, prv_key_file, password);
-            if(!prvkey)
-            {
-                AXIS2_LOG_ERROR(env->log, AXIS2_LOG_SI,
-                                "[rampart][rampart_signature] Cannot load the private key from file.");
-                return AXIS2_FAILURE;
-            }
-        }
-        else
-        {
-            AXIS2_LOG_ERROR(env->log, AXIS2_LOG_SI,
-                            "[rampart][rampart_signature] Unknown Private key format.");
-            return AXIS2_FAILURE;
-        }
+        AXIS2_LOG_ERROR(env->log, AXIS2_LOG_SI,
+                "[rampart][rampart_signature]Private key cannot be loaded.");
+		return AXIS2_FAILURE;
     }
 
     /*Get the asymmetric signature algorithm*/
@@ -517,6 +391,7 @@ rampart_sig_sign_message(
     rp_property_type_t token_type;
     rp_property_type_t binding_type;
     rp_property_t *token = NULL;
+    axis2_char_t *derived_key_version = NULL;
     axiom_node_t *sig_node = NULL;
     axis2_char_t *eki = NULL;
     axis2_bool_t is_direct_reference = AXIS2_TRUE;
@@ -625,6 +500,7 @@ rampart_sig_sign_message(
     include = rampart_context_is_token_include(rampart_context, token, 
                                                 token_type, server_side, 
                                                 AXIS2_FALSE, env);
+    derived_key_version = rampart_context_get_derived_key_version(env, token);
     if (token_type == RP_PROPERTY_X509_TOKEN) 
     {        
 		if (include) 
@@ -661,9 +537,9 @@ rampart_sig_sign_message(
             axiom_node_t *security_context_token_node = NULL;
             /*include the security context token and set the AttachedReference to key_reference_node*/
             security_context_token_node = oxs_axiom_get_node_by_local_name(env, sec_node,  OXS_NODE_SECURITY_CONTEXT_TOKEN);
-            if((!security_context_token_node) || (is_different_session_key_for_encryption_and_signing(env, rampart_context)))
+            if((!security_context_token_node) || (rampart_context_is_different_session_key_for_enc_and_sign(env, rampart_context)))
             {
-                security_context_token_node = sct_provider_get_token(env, token, server_side, AXIS2_FALSE, rampart_context, msg_ctx);
+                security_context_token_node = sct_provider_get_token(env, token, AXIS2_FALSE, rampart_context, msg_ctx);
                 if(!security_context_token_node)
                 {
                     AXIS2_LOG_ERROR(env->log, AXIS2_LOG_SI,
@@ -674,12 +550,53 @@ rampart_sig_sign_message(
                 }
                 axiom_node_add_child(sec_node, env, security_context_token_node);
             }
-            key_reference_node = sct_provider_get_attached_reference(env, token, server_side, AXIS2_FALSE, rampart_context, msg_ctx);
+            key_reference_node = sct_provider_get_attached_reference(env, token, AXIS2_FALSE, rampart_context, msg_ctx);
         }
         else
         {
             /*get the unattachedReference and set to key_reference_node*/
-            key_reference_node = sct_provider_get_unattached_reference(env, token, server_side, AXIS2_FALSE, rampart_context, msg_ctx);
+            key_reference_node = sct_provider_get_unattached_reference(env, token, AXIS2_FALSE, rampart_context, msg_ctx);
+        }
+    }
+    else if (token_type == RP_PROPERTY_SAML_TOKEN)
+    {
+        if (include)
+        {
+            axiom_node_t *assertion = NULL;
+            rampart_saml_token_t *saml = NULL;
+            /* Get the saml info from context.First check weather it is a signature token.*/
+            saml = rampart_context_get_saml_token(rampart_context, env, RAMPART_ST_TYPE_SIGNATURE_TOKEN);            
+            if (!saml)
+            {
+                saml = rampart_context_get_saml_token(rampart_context, env, RAMPART_ST_TYPE_PROTECTION_TOKEN);            
+            }
+            if (!saml)
+            {
+                AXIS2_LOG_ERROR(env->log, AXIS2_LOG_SI,"[rampart][rampart_signature] SAML token not specified.");
+                return AXIS2_FAILURE;
+            }
+            /* If not already added to the header */
+            if (!rampart_saml_token_is_added_to_header(saml, env))            
+            {
+                assertion = rampart_saml_token_get_assertion(saml, env);
+                if (!assertion) 
+                {
+                    AXIS2_LOG_ERROR(env->log, AXIS2_LOG_SI,"[rampart][rampart_signature] SAML token not specified.");
+                    return AXIS2_FAILURE;
+                }
+				axiom_node_add_child(sec_node, env, assertion);
+                /* we are sure that key reference node is not added to the header */
+                key_reference_node = rampart_saml_token_get_str(saml, env);            
+                if (!key_reference_node)
+                {
+                    key_reference_node = oxs_saml_token_build_key_identifier_reference_local(env, NULL, assertion);
+                }                
+            }            
+        }
+        else
+        {
+            AXIS2_LOG_ERROR(env->log, AXIS2_LOG_SI,"[rampart][rampart_signature] SAML tokens with unattached reference not supported.");
+            return AXIS2_FAILURE;
         }
     }
 
@@ -745,11 +662,31 @@ rampart_sig_sign_message(
                 /*We have used a derived key to sign. Note the NULL we pass for the enc_key_id*/
                 rampart_sig_prepare_key_info_for_sym_binding(env, rampart_context, sign_ctx, sig_node, signed_key, NULL);
                 /*In addition we need to add a DerivedKeyToken*/
-                dk_token = oxs_derivation_build_derived_key_token_with_stre(env, signed_key, sec_node, key_reference_node);
+                dk_token = oxs_derivation_build_derived_key_token_with_stre(env, signed_key, sec_node, key_reference_node, derived_key_version);
                 /*We need to make DerivedKeyToken to appear before the sginature node*/
                 oxs_axiom_interchange_nodes(env, dk_token, sig_node);
             }
         }
+		else if(token_type == RP_PROPERTY_SAML_TOKEN)
+		{
+			if(0 == axutil_strcmp(oxs_key_get_name(session_key, env), oxs_key_get_name(signed_key, env))) 
+            {
+                /*Now then... we have used the security context token to sign*/
+                axiom_node_t* key_info_node = NULL;
+                key_info_node = oxs_token_build_key_info_element(env, sig_node);
+                axiom_node_add_child(key_info_node, env, key_reference_node);
+            }
+            else
+            {
+                axiom_node_t *dk_token = NULL;
+                /*We have used a derived key to sign. Note the NULL we pass for the enc_key_id*/
+                rampart_sig_prepare_key_info_for_sym_binding(env, rampart_context, sign_ctx, sig_node, signed_key, NULL);
+                /*In addition we need to add a DerivedKeyToken*/
+                dk_token = oxs_derivation_build_derived_key_token_with_stre(env, signed_key, sec_node, key_reference_node, derived_key_version);
+                /*We need to make DerivedKeyToken to appear before the sginature node*/
+                oxs_axiom_interchange_nodes(env, dk_token, sig_node);
+            }
+		}
         else
         {
             if(server_side)
@@ -775,7 +712,7 @@ rampart_sig_sign_message(
                     /*We have used a derived key to sign. Note the NULL we pass for the enc_key_id*/
                     rampart_sig_prepare_key_info_for_sym_binding(env, rampart_context, sign_ctx, sig_node, signed_key, NULL);
                     /*In addition we need to add a DerivedKeyToken*/
-                    dk_token = oxs_derivation_build_derived_key_token_with_stre(env, signed_key, sec_node, key_reference_node);
+                    dk_token = oxs_derivation_build_derived_key_token_with_stre(env, signed_key, sec_node, key_reference_node, derived_key_version);
                     /*We need to make DerivedKeyToken to appear before the sginature node*/
                     oxs_axiom_interchange_nodes(env, dk_token, sig_node);
                 }
@@ -791,7 +728,7 @@ rampart_sig_sign_message(
                 if(!encrypted_key_node)
                 {
                     /*There is no EncryptedKey so generate one*/
-                    status = rampart_enc_encrypt_session_key(env, session_key, msg_ctx, rampart_context, soap_envelope, sec_node, NULL );
+                    status = rampart_enc_encrypt_session_key(env, session_key, msg_ctx, rampart_context, sec_node, NULL );
                     if(AXIS2_FAILURE == status)
                     {
                         AXIS2_LOG_ERROR(env->log, AXIS2_LOG_SI, "[rampart][rampart_signature] Cannot encrypt the session key " );
@@ -824,7 +761,7 @@ rampart_sig_sign_message(
                     /*We have used a derived key to sign. Note the NULL we pass for the enc_key_id*/
                     rampart_sig_prepare_key_info_for_sym_binding(env, rampart_context, sign_ctx, sig_node, signed_key, NULL  );
                     /*In addition we need to add a DerivedKeyToken after the EncryptedKey*/
-                    dk_token = oxs_derivation_build_derived_key_token(env, signed_key, sec_node, enc_key_id ,OXS_WSS_11_VALUE_TYPE_ENCRYPTED_KEY);
+                    dk_token = oxs_derivation_build_derived_key_token(env, signed_key, sec_node, enc_key_id ,OXS_WSS_11_VALUE_TYPE_ENCRYPTED_KEY, derived_key_version);
                     /*We need to make DerivedKeyToken to appear before the sginature node*/
                     oxs_axiom_interchange_nodes(env, dk_token, sig_node);
                 }
@@ -903,12 +840,14 @@ rampart_sig_add_x509_token(const axutil_env_t *env,
     oxs_x509_cert_t *cert = NULL;
     axiom_node_t *bst_node = NULL;    
     axis2_char_t *bst_data = NULL;
-    
+    oxs_key_mgr_t *key_mgr = NULL;
+
+	key_mgr = rampart_context_get_key_mgr(rampart_context, env);
     /* 
      * If the requirement is to include the token we should build the binary security
      * token element here.
      */
-    cert = rampart_sig_get_cert(env, rampart_context);
+    cert = oxs_key_mgr_get_certificate(key_mgr, env);
     if (!cert)
     {
         AXIS2_LOG_ERROR(env->log, AXIS2_LOG_SI,
